summaryrefslogtreecommitdiffstats
path: root/libkdepim/qutf7codec.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'libkdepim/qutf7codec.cpp')
-rw-r--r--libkdepim/qutf7codec.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/libkdepim/qutf7codec.cpp b/libkdepim/qutf7codec.cpp
index 11c0db92..bbee2d8c 100644
--- a/libkdepim/qutf7codec.cpp
+++ b/libkdepim/qutf7codec.cpp
@@ -18,7 +18,7 @@
with any version of Qt by TrollTech AS, Norway. In this case, the
use of this plugin doesn't cause the resulting executable to be
covered by the GNU General Public License.
- This exception does not however invalidate any other reasons why the
+ This exception does not however tqinvalidate any other reasons why the
executable file might be covered by the GNU General Public License.
*/
@@ -137,10 +137,10 @@ int QUtf7Codec::heuristicContentMatch(const char* chars, int len) const
}
class QUtf7Decoder : public TQTextDecoder {
// the storage for our unicode char until it's finished
ushort uc;
// the state of the base64 decoding
// can be 0 (just finished three unicode chars)
// 1 (have the upper 6 bits of uc already)
// 2 (have the upper 12 bits of uc already)
// 3 (have the upper 2 bits of uc already)
@@ -148,7 +148,7 @@ class QUtf7Decoder : public TQTextDecoder {
// 7 (have the upper 10 bits of uc already)
// => n (have the upper (n * 6) % 16 bits of uc already)
// "stepNo" cycles through all it's values every three
- // unicode chars.
+ // tqunicode chars.
char stepNo;
// remembers if we are in shifted-sequence mode
bool shifted;
@@ -183,7 +183,7 @@ public:
qWarning("QUtf7Decoder: 8bit char found in input. "
"Parser has been re-initialized!");
resetParser();
- result += TQChar::replacement;
+ result += TQChar::tqreplacement;
continue;
}
@@ -374,8 +374,8 @@ private:
// if mayContinue, this char has already been written
*t++ = toBase64( outbits | ( u >> 14 ) );
}
- *t++ = toBase64( (u & 0x3F00 /* mask top 2 bits */ ) >> 8 );
- *t++ = toBase64( (u & 0x00FC /* mask msbyte */ ) >> 2 );
+ *t++ = toBase64( (u & 0x3F00 /* tqmask top 2 bits */ ) >> 8 );
+ *t++ = toBase64( (u & 0x00FC /* tqmask msbyte */ ) >> 2 );
// save 2 lowest-significant bits in outbits[5..4]
outbits = (u & 0x0003) << 4;
break;
@@ -462,7 +462,7 @@ public:
#endif
// source and destination cursor
- const TQChar * s = uc.unicode();
+ const TQChar * s = uc.tqunicode();
TQCString::Iterator t = result.data();
if ( uc.isNull() ) {
@@ -473,7 +473,7 @@ public:
// normal operation:
for (int i = 0 ; i < len_in_out ;
i++/*, checkOutBuf(result,maxreslen,t,i,len_in_out,5)*/ ) {
- ushort ch = s[i].unicode();
+ ushort ch = s[i].tqunicode();
//
// first, we check whether we might get around encoding:
@@ -137,10 +137,10 @@ int QUtf7Codec::heuristicContentMatch(const char* chars, int len) const
}
class QUtf7Decoder : public TQTextDecoder {
- // the storage for our unicode char until it's finished
+ // the storage for our tqunicode char until it's finished
ushort uc;
// the state of the base64 decoding
@@ -137,10 +137,10 @@ int QUtf7Codec::heuristicContentMatch(const char* chars, int len) const
ushort uc;
// the state of the base64 decoding
- // can be 0 (just finished three unicode chars)
+ // can be 0 (just finished three tqunicode chars)
// 1 (have the upper 6 bits of uc already)
// 2 (have the upper 12 bits of uc already)